//
// JTypist v3.1 - Java typing tutor program for UNIX systems
// Copyright (C) 2000  Simon Baldwin (simonb@sco.com)
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//
//
// InitProgressGUI class - create a 'starting, please wait' dialog
//
import java.awt.Frame;
import java.awt.Font;
import java.awt.Panel;
import java.awt.BorderLayout;
import java.awt.GridLayout;
import java.awt.Label;
import java.awt.event.WindowListener;
import java.awt.event.WindowEvent;
import java.util.ResourceBundle;
import java.text.MessageFormat;

/**
 * Create a 'starting, please wait' dialog.
 */
public class InitProgressGUI extends Frame
		implements WindowListener {
	private boolean inAnApplet = true;

	// message and colour catalog information
	private static final ResourceBundle	messages	=
				ResourceBundle.getBundle( "MessageResource" );
	private static final ResourceBundle	colours		=
				ResourceBundle.getBundle( "ColorResource" );

	// GUI components
	private Label		heading_label;
	private Gauge		progress_gauge;

	// the anticipated number of calls that will be made to the checkpoint
	// method, and a calculation of the percentage progress that is made
	// based on that anticipated number
	private int		expected_checkpoints	= 100;
	private int		pc_progress		= 0;


	/**
	 * Initialize the whole GUI set.
	 */
	public InitProgressGUI( boolean inAnApplet,
			int expected_checkpoints, String heading ) {
		this.addWindowListener( this );
		this.inAnApplet = inAnApplet;

		// keep the number of expected checkpoint calls
		this.expected_checkpoints = expected_checkpoints;

		// create GUI components
		setTitle( messages.getString( "InitProgressGUI.title" ));
		setLayout( new BorderLayout() );
		setForeground( Colour.find_colour(
			colours.getString( "InitProgressGUI.foreground" )));
		setBackground( Colour.find_colour(
			colours.getString( "InitProgressGUI.background" )));
		setFont( Font.decode(
			colours.getString( "InitProgressGUI.font" )));

		// create the label and progress gauge
		Panel panel = new Panel();
		panel.setLayout( new GridLayout( 0, 1 ));
		panel.add( new Label( heading ));
		progress_gauge = new Gauge( 0, 100, 0,
			messages.getString( "InitProgressGUI.pc" ), "" );
		progress_gauge.setBackground( Colour.find_colour(
			colours.getString( "InitProgressGUI.gaugebg" )));
		progress_gauge.setForeground( Colour.find_colour(
			colours.getString( "InitProgressGUI.gaugetext" )));
		progress_gauge.set_colour( Colour.find_colour(
			colours.getString( "InitProgressGUI.gaugebar" )));
		panel.add( progress_gauge );
		add( "Center", panel );
	}


	/**
	 * Update the progress gauge, called when init reaches
	 * one of several defined checkpoints.
	 */
	public void checkpoint() {

		// update the percentage progress as best we can - remember
		// that this is just an estimate
		pc_progress += 100 / expected_checkpoints;

		// clamp any silly values
		if ( pc_progress < 0 ) pc_progress = 0;
		if ( pc_progress > 100 ) pc_progress = 100;

		// finally set our gauge to where we are
		progress_gauge.set_value( pc_progress );
	}


	/*
	 * Handle GUI component actions and events.
	 */
	public void windowClosing( WindowEvent evt ) {
		setVisible( false );
	}
	public void windowClosed( WindowEvent evt ) {}
	public void windowOpened( WindowEvent evt ) {}
	public void windowIconified( WindowEvent evt ) {}
	public void windowDeiconified( WindowEvent evt ) {}
	public void windowActivated( WindowEvent evt ) {}
	public void windowDeactivated( WindowEvent evt ) {}


	/**
	 * Class test code.
	 */
	public static void main( String args[] ) {
		System.out.println( "*** CLASS TEST CODE ***" );

		InitProgressGUI cinit = new InitProgressGUI( false, 20,
				"Heading line, something about starting..." );
		cinit.pack(); cinit.setVisible( true );
		for ( int pc = 0; pc <= 100; pc += 5 ) {
			cinit.checkpoint();
			try { Thread.sleep( 500 ); }
			catch ( InterruptedException e ) {}
		}
	}
}
